package sun.util.locale.provider;

import java.util.Collections;
import java.util.ResourceBundle;
import java.util.HashSet;
import java.util.concurrent.ConcurrentHashMap;
import java.util.spi.LocaleNameProvider;
import java.util.Currency;
import java.util.spi.CurrencyNameProvider;
import java.util.Calendar;
import java.util.TimeZone;
import sun.util.spi.CalendarProvider;
import java.util.spi.CalendarDataProvider;
import java.text.spi.DecimalFormatSymbolsProvider;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.spi.NumberFormatProvider;
import java.text.spi.DateFormatSymbolsProvider;
import java.text.SimpleDateFormat;
import java.text.DateFormat;
import java.text.spi.DateFormatProvider;
import java.util.Set;
import java.text.DecimalFormatSymbols;
import java.text.DateFormatSymbols;
import java.util.concurrent.atomic.AtomicReferenceArray;
import java.lang.ref.SoftReference;
import java.util.Locale;
import java.util.concurrent.ConcurrentMap;

public class HostLocaleProviderAdapterImpl
{
    private static final int CAT_DISPLAY = 0;
    private static final int CAT_FORMAT = 1;
    private static final int NF_NUMBER = 0;
    private static final int NF_CURRENCY = 1;
    private static final int NF_PERCENT = 2;
    private static final int NF_INTEGER = 3;
    private static final int NF_MAX = 3;
    private static final int CD_FIRSTDAYOFWEEK = 0;
    private static final int CD_MINIMALDAYSINFIRSTWEEK = 1;
    private static final int DN_CURRENCY_NAME = 0;
    private static final int DN_CURRENCY_SYMBOL = 1;
    private static final int DN_LOCALE_LANGUAGE = 2;
    private static final int DN_LOCALE_SCRIPT = 3;
    private static final int DN_LOCALE_REGION = 4;
    private static final int DN_LOCALE_VARIANT = 5;
    private static final String[] calIDToLDML;
    private static ConcurrentMap<Locale, SoftReference<AtomicReferenceArray<String>>> dateFormatCache;
    private static ConcurrentMap<Locale, SoftReference<DateFormatSymbols>> dateFormatSymbolsCache;
    private static ConcurrentMap<Locale, SoftReference<AtomicReferenceArray<String>>> numberFormatCache;
    private static ConcurrentMap<Locale, SoftReference<DecimalFormatSymbols>> decimalFormatSymbolsCache;
    private static final Set<Locale> supportedLocaleSet;
    private static final String nativeDisplayLanguage;
    private static final Locale[] supportedLocale;
    
    public HostLocaleProviderAdapterImpl() {
    }
    
    public static DateFormatProvider getDateFormatProvider() {
        return new DateFormatProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$000();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$100(locale);
            }
            
            @Override
            public DateFormat getDateInstance(int n, Locale locale) {
                return new SimpleDateFormat((String)this.getDateTimePatterns(locale).get(n / 2), HostLocaleProviderAdapterImpl.access$200(locale));
            }
            
            @Override
            public DateFormat getTimeInstance(int n, Locale locale) {
                return new SimpleDateFormat((String)this.getDateTimePatterns(locale).get(n / 2 + 2), HostLocaleProviderAdapterImpl.access$200(locale));
            }
            
            @Override
            public DateFormat getDateTimeInstance(int n, int n2, Locale locale) {
                AtomicReferenceArray<String> dateTimePatterns = this.getDateTimePatterns(locale);
                return new SimpleDateFormat((String)dateTimePatterns.get(n / 2) + " " + (String)dateTimePatterns.get(n2 / 2 + 2), HostLocaleProviderAdapterImpl.access$200(locale));
            }
            
            private AtomicReferenceArray<String> getDateTimePatterns(Locale locale) {
                SoftReference<Object> softReference = (SoftReference)HostLocaleProviderAdapterImpl.dateFormatCache.get(locale);
                AtomicReferenceArray referent;
                if (softReference == null || (referent = (AtomicReferenceArray)softReference.get()) == null) {
                    String languageTag = HostLocaleProviderAdapterImpl.access$400(locale).toLanguageTag();
                    referent = new AtomicReferenceArray(4);
                    referent.compareAndSet(0, null, HostLocaleProviderAdapterImpl.access$600(HostLocaleProviderAdapterImpl.access$500(1, -1, languageTag)));
                    referent.compareAndSet(1, null, HostLocaleProviderAdapterImpl.access$600(HostLocaleProviderAdapterImpl.access$500(3, -1, languageTag)));
                    referent.compareAndSet(2, null, HostLocaleProviderAdapterImpl.access$600(HostLocaleProviderAdapterImpl.access$500(-1, 1, languageTag)));
                    referent.compareAndSet(3, null, HostLocaleProviderAdapterImpl.access$600(HostLocaleProviderAdapterImpl.access$500(-1, 3, languageTag)));
                    HostLocaleProviderAdapterImpl.dateFormatCache.put(locale, new SoftReference(referent));
                    return referent;
                }
                return referent;
            }
        };
    }
    
    public static DateFormatSymbolsProvider getDateFormatSymbolsProvider() {
        return new DateFormatSymbolsProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$000();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$100(locale);
            }
            
            @Override
            public DateFormatSymbols getInstance(Locale locale) {
                SoftReference<Object> softReference = (SoftReference)HostLocaleProviderAdapterImpl.dateFormatSymbolsCache.get(locale);
                DateFormatSymbols referent;
                if (softReference == null || (referent = (DateFormatSymbols)softReference.get()) == null) {
                    referent = new DateFormatSymbols(locale);
                    String languageTag = HostLocaleProviderAdapterImpl.access$400(locale).toLanguageTag();
                    referent.setAmPmStrings(HostLocaleProviderAdapterImpl.access$800(languageTag, referent.getAmPmStrings()));
                    referent.setEras(HostLocaleProviderAdapterImpl.access$900(languageTag, referent.getEras()));
                    referent.setMonths(HostLocaleProviderAdapterImpl.access$1000(languageTag, referent.getMonths()));
                    referent.setShortMonths(HostLocaleProviderAdapterImpl.access$1100(languageTag, referent.getShortMonths()));
                    referent.setWeekdays(HostLocaleProviderAdapterImpl.access$1200(languageTag, referent.getWeekdays()));
                    referent.setShortWeekdays(HostLocaleProviderAdapterImpl.access$1300(languageTag, referent.getShortWeekdays()));
                    HostLocaleProviderAdapterImpl.dateFormatSymbolsCache.put(locale, new SoftReference(referent));
                }
                return (DateFormatSymbols)referent.clone();
            }
        };
    }
    
    public static NumberFormatProvider getNumberFormatProvider() {
        return new NumberFormatProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$1400();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$1500(locale);
            }
            
            @Override
            public NumberFormat getCurrencyInstance(Locale locale) {
                return new DecimalFormat((String)this.getNumberPatterns(locale).get(1), DecimalFormatSymbols.getInstance(locale));
            }
            
            @Override
            public NumberFormat getIntegerInstance(Locale locale) {
                return new DecimalFormat((String)this.getNumberPatterns(locale).get(3), DecimalFormatSymbols.getInstance(locale));
            }
            
            @Override
            public NumberFormat getNumberInstance(Locale locale) {
                return new DecimalFormat((String)this.getNumberPatterns(locale).get(0), DecimalFormatSymbols.getInstance(locale));
            }
            
            @Override
            public NumberFormat getPercentInstance(Locale locale) {
                return new DecimalFormat((String)this.getNumberPatterns(locale).get(2), DecimalFormatSymbols.getInstance(locale));
            }
            
            private AtomicReferenceArray<String> getNumberPatterns(Locale locale) {
                SoftReference<Object> softReference = (SoftReference)HostLocaleProviderAdapterImpl.numberFormatCache.get(locale);
                AtomicReferenceArray referent;
                if (softReference == null || (referent = (AtomicReferenceArray)softReference.get()) == null) {
                    String languageTag = locale.toLanguageTag();
                    referent = new AtomicReferenceArray(4);
                    for (int i = 0; i <= 3; ++i) {
                        referent.compareAndSet(i, null, HostLocaleProviderAdapterImpl.access$1700(i, languageTag));
                    }
                    HostLocaleProviderAdapterImpl.numberFormatCache.put(locale, new SoftReference(referent));
                    return referent;
                }
                return referent;
            }
        };
    }
    
    public static DecimalFormatSymbolsProvider getDecimalFormatSymbolsProvider() {
        return new DecimalFormatSymbolsProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$1400();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$1500(locale);
            }
            
            @Override
            public DecimalFormatSymbols getInstance(Locale locale) {
                SoftReference<Object> softReference = (SoftReference)HostLocaleProviderAdapterImpl.decimalFormatSymbolsCache.get(locale);
                DecimalFormatSymbols referent;
                if (softReference == null || (referent = (DecimalFormatSymbols)softReference.get()) == null) {
                    referent = new DecimalFormatSymbols(HostLocaleProviderAdapterImpl.access$1900(locale));
                    String languageTag = HostLocaleProviderAdapterImpl.access$400(locale).toLanguageTag();
                    referent.setInternationalCurrencySymbol(HostLocaleProviderAdapterImpl.access$2000(languageTag, referent.getInternationalCurrencySymbol()));
                    referent.setCurrencySymbol(HostLocaleProviderAdapterImpl.access$2100(languageTag, referent.getCurrencySymbol()));
                    referent.setDecimalSeparator(HostLocaleProviderAdapterImpl.access$2200(languageTag, referent.getDecimalSeparator()));
                    referent.setGroupingSeparator(HostLocaleProviderAdapterImpl.access$2300(languageTag, referent.getGroupingSeparator()));
                    referent.setInfinity(HostLocaleProviderAdapterImpl.access$2400(languageTag, referent.getInfinity()));
                    referent.setMinusSign(HostLocaleProviderAdapterImpl.access$2500(languageTag, referent.getMinusSign()));
                    referent.setMonetaryDecimalSeparator(HostLocaleProviderAdapterImpl.access$2600(languageTag, referent.getMonetaryDecimalSeparator()));
                    referent.setNaN(HostLocaleProviderAdapterImpl.access$2700(languageTag, referent.getNaN()));
                    referent.setPercent(HostLocaleProviderAdapterImpl.access$2800(languageTag, referent.getPercent()));
                    referent.setPerMill(HostLocaleProviderAdapterImpl.access$2900(languageTag, referent.getPerMill()));
                    referent.setZeroDigit(HostLocaleProviderAdapterImpl.access$3000(languageTag, referent.getZeroDigit()));
                    HostLocaleProviderAdapterImpl.decimalFormatSymbolsCache.put(locale, new SoftReference(referent));
                }
                return (DecimalFormatSymbols)referent.clone();
            }
        };
    }
    
    public static CalendarDataProvider getCalendarDataProvider() {
        return new CalendarDataProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$000();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$100(locale);
            }
            
            @Override
            public int getFirstDayOfWeek(Locale locale) {
                int access$3100 = HostLocaleProviderAdapterImpl.access$3100(HostLocaleProviderAdapterImpl.access$400(locale).toLanguageTag(), 0);
                if (access$3100 != -1) {
                    return (access$3100 + 1) % 7 + 1;
                }
                return 0;
            }
            
            @Override
            public int getMinimalDaysInFirstWeek(Locale locale) {
                return 0;
            }
        };
    }
    
    public static CalendarProvider getCalendarProvider() {
        return new CalendarProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.access$000();
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.access$100(locale);
            }
            
            @Override
            public Calendar getInstance(TimeZone timeZone, Locale locale) {
                return new Calendar.Builder().setLocale(HostLocaleProviderAdapterImpl.access$200(locale)).setTimeZone(timeZone).setInstant(System.currentTimeMillis()).build();
            }
        };
    }
    
    public static CurrencyNameProvider getCurrencyNameProvider() {
        return new CurrencyNameProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.supportedLocale;
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(locale.stripExtensions()) && locale.getLanguage().equals(HostLocaleProviderAdapterImpl.nativeDisplayLanguage);
            }
            
            @Override
            public String getSymbol(String anObject, Locale locale) {
                try {
                    if (Currency.getInstance(locale).getCurrencyCode().equals(anObject)) {
                        return HostLocaleProviderAdapterImpl.access$3500(locale.toLanguageTag(), 1, anObject);
                    }
                }
                catch (IllegalArgumentException ex) {}
                return null;
            }
            
            @Override
            public String getDisplayName(String anObject, Locale locale) {
                try {
                    if (Currency.getInstance(locale).getCurrencyCode().equals(anObject)) {
                        return HostLocaleProviderAdapterImpl.access$3500(locale.toLanguageTag(), 0, anObject);
                    }
                }
                catch (IllegalArgumentException ex) {}
                return null;
            }
        };
    }
    
    public static LocaleNameProvider getLocaleNameProvider() {
        return new LocaleNameProvider() {
            @Override
            public Locale[] getAvailableLocales() {
                return HostLocaleProviderAdapterImpl.supportedLocale;
            }
            
            @Override
            public boolean isSupportedLocale(Locale locale) {
                return HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(locale.stripExtensions()) && locale.getLanguage().equals(HostLocaleProviderAdapterImpl.nativeDisplayLanguage);
            }
            
            @Override
            public String getDisplayLanguage(String s, Locale locale) {
                return HostLocaleProviderAdapterImpl.access$3500(locale.toLanguageTag(), 2, s);
            }
            
            @Override
            public String getDisplayCountry(String str, Locale locale) {
                return HostLocaleProviderAdapterImpl.access$3500(locale.toLanguageTag(), 4, HostLocaleProviderAdapterImpl.nativeDisplayLanguage + "-" + str);
            }
            
            @Override
            public String getDisplayScript(String s, Locale locale) {
                return null;
            }
            
            @Override
            public String getDisplayVariant(String s, Locale locale) {
                return null;
            }
        };
    }
    
    private static String convertDateTimePattern(String s) {
        return s.replaceAll("dddd", "EEEE").replaceAll("ddd", "EEE").replaceAll("tt", "aa").replaceAll("g", "GG");
    }
    
    private static Locale[] getSupportedCalendarLocales() {
        if (HostLocaleProviderAdapterImpl.supportedLocale.length != 0 && HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(Locale.JAPAN) && isJapaneseCalendar()) {
            Locale[] array = new Locale[HostLocaleProviderAdapterImpl.supportedLocale.length + 1];
            array[0] = JRELocaleConstants.JA_JP_JP;
            System.arraycopy(HostLocaleProviderAdapterImpl.supportedLocale, 0, array, 1, HostLocaleProviderAdapterImpl.supportedLocale.length);
            return array;
        }
        return HostLocaleProviderAdapterImpl.supportedLocale;
    }
    
    private static boolean isSupportedCalendarLocale(Locale build) {
        if (build.hasExtensions() || build.getVariant() != "") {
            build = new Locale.Builder().setLocale(build).clearExtensions().build();
        }
        if (!HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(build)) {
            return false;
        }
        int calendarID = getCalendarID(build.toLanguageTag());
        if (calendarID <= 0 || calendarID >= HostLocaleProviderAdapterImpl.calIDToLDML.length) {
            return false;
        }
        String unicodeLocaleType = build.getUnicodeLocaleType("ca");
        String replaceFirst = HostLocaleProviderAdapterImpl.calIDToLDML[calendarID].replaceFirst("_.*", "");
        if (unicodeLocaleType == null) {
            return Calendar.getAvailableCalendarTypes().contains(replaceFirst);
        }
        return unicodeLocaleType.equals(replaceFirst);
    }
    
    private static Locale[] getSupportedNativeDigitLocales() {
        if (HostLocaleProviderAdapterImpl.supportedLocale.length != 0 && HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(JRELocaleConstants.TH_TH) && isNativeDigit("th-TH")) {
            Locale[] array = new Locale[HostLocaleProviderAdapterImpl.supportedLocale.length + 1];
            array[0] = JRELocaleConstants.TH_TH_TH;
            System.arraycopy(HostLocaleProviderAdapterImpl.supportedLocale, 0, array, 1, HostLocaleProviderAdapterImpl.supportedLocale.length);
            return array;
        }
        return HostLocaleProviderAdapterImpl.supportedLocale;
    }
    
    private static boolean isSupportedNativeDigitLocale(Locale stripExtensions) {
        if (JRELocaleConstants.TH_TH_TH.equals(stripExtensions)) {
            return isNativeDigit("th-TH");
        }
        String unicodeLocaleType = null;
        if (stripExtensions.hasExtensions()) {
            unicodeLocaleType = stripExtensions.getUnicodeLocaleType("nu");
            stripExtensions = stripExtensions.stripExtensions();
        }
        if (HostLocaleProviderAdapterImpl.supportedLocaleSet.contains(stripExtensions)) {
            if (unicodeLocaleType == null || unicodeLocaleType.equals("latn")) {
                return true;
            }
            if (stripExtensions.getLanguage().equals("th")) {
                return "thai".equals(unicodeLocaleType) && isNativeDigit(stripExtensions.toLanguageTag());
            }
        }
        return false;
    }
    
    private static Locale removeExtensions(Locale locale) {
        return new Locale.Builder().setLocale(locale).clearExtensions().build();
    }
    
    private static boolean isJapaneseCalendar() {
        return getCalendarID("ja-JP") == 3;
    }
    
    private static Locale getCalendarLocale(Locale locale) {
        int calendarID = getCalendarID(locale.toLanguageTag());
        if (calendarID > 0 && calendarID < HostLocaleProviderAdapterImpl.calIDToLDML.length) {
            Locale.Builder builder = new Locale.Builder();
            String[] split = HostLocaleProviderAdapterImpl.calIDToLDML[calendarID].split("_");
            if (split.length > 1) {
                builder.setLocale(Locale.forLanguageTag(split[1]));
            }
            else {
                builder.setLocale(locale);
            }
            builder.setUnicodeLocaleKeyword("ca", split[0]);
            return builder.build();
        }
        else {
            return locale;
        }
    }
    
    private static Locale getNumberLocale(Locale locale) {
        if (JRELocaleConstants.TH_TH.equals(locale) && isNativeDigit("th-TH")) {
            Locale.Builder setLocale = new Locale.Builder().setLocale(locale);
            setLocale.setUnicodeLocaleKeyword("nu", "thai");
            return setLocale.build();
        }
        return locale;
    }
    
    private static native boolean initialize();
    
    private static native String getDefaultLocale(int p0);
    
    private static native String getDateTimePattern(int p0, int p1, String p2);
    
    private static native int getCalendarID(String p0);
    
    private static native String[] getAmPmStrings(String p0, String[] p1);
    
    private static native String[] getEras(String p0, String[] p1);
    
    private static native String[] getMonths(String p0, String[] p1);
    
    private static native String[] getShortMonths(String p0, String[] p1);
    
    private static native String[] getWeekdays(String p0, String[] p1);
    
    private static native String[] getShortWeekdays(String p0, String[] p1);
    
    private static native String getNumberPattern(int p0, String p1);
    
    private static native boolean isNativeDigit(String p0);
    
    private static native String getCurrencySymbol(String p0, String p1);
    
    private static native char getDecimalSeparator(String p0, char p1);
    
    private static native char getGroupingSeparator(String p0, char p1);
    
    private static native String getInfinity(String p0, String p1);
    
    private static native String getInternationalCurrencySymbol(String p0, String p1);
    
    private static native char getMinusSign(String p0, char p1);
    
    private static native char getMonetaryDecimalSeparator(String p0, char p1);
    
    private static native String getNaN(String p0, String p1);
    
    private static native char getPercent(String p0, char p1);
    
    private static native char getPerMill(String p0, char p1);
    
    private static native char getZeroDigit(String p0, char p1);
    
    private static native int getCalendarDataValue(String p0, int p1);
    
    private static native String getDisplayString(String p0, int p1, String p2);
    
    static Locale[] access$000() {
        return getSupportedCalendarLocales();
    }
    
    static boolean access$100(Locale locale) {
        return isSupportedCalendarLocale(locale);
    }
    
    static Locale access$200(Locale locale) {
        return getCalendarLocale(locale);
    }
    
    static Locale access$400(Locale locale) {
        return removeExtensions(locale);
    }
    
    static String access$500(int n, int n2, String s) {
        return getDateTimePattern(n, n2, s);
    }
    
    static String access$600(String s) {
        return convertDateTimePattern(s);
    }
    
    static String[] access$800(String s, String[] array) {
        return getAmPmStrings(s, array);
    }
    
    static String[] access$900(String s, String[] array) {
        return getEras(s, array);
    }
    
    static String[] access$1000(String s, String[] array) {
        return getMonths(s, array);
    }
    
    static String[] access$1100(String s, String[] array) {
        return getShortMonths(s, array);
    }
    
    static String[] access$1200(String s, String[] array) {
        return getWeekdays(s, array);
    }
    
    static String[] access$1300(String s, String[] array) {
        return getShortWeekdays(s, array);
    }
    
    static Locale[] access$1400() {
        return getSupportedNativeDigitLocales();
    }
    
    static boolean access$1500(Locale locale) {
        return isSupportedNativeDigitLocale(locale);
    }
    
    static String access$1700(int n, String s) {
        return getNumberPattern(n, s);
    }
    
    static Locale access$1900(Locale locale) {
        return getNumberLocale(locale);
    }
    
    static String access$2000(String s, String s2) {
        return getInternationalCurrencySymbol(s, s2);
    }
    
    static String access$2100(String s, String s2) {
        return getCurrencySymbol(s, s2);
    }
    
    static char access$2200(String s, char c) {
        return getDecimalSeparator(s, c);
    }
    
    static char access$2300(String s, char c) {
        return getGroupingSeparator(s, c);
    }
    
    static String access$2400(String s, String s2) {
        return getInfinity(s, s2);
    }
    
    static char access$2500(String s, char c) {
        return getMinusSign(s, c);
    }
    
    static char access$2600(String s, char c) {
        return getMonetaryDecimalSeparator(s, c);
    }
    
    static String access$2700(String s, String s2) {
        return getNaN(s, s2);
    }
    
    static char access$2800(String s, char c) {
        return getPercent(s, c);
    }
    
    static char access$2900(String s, char c) {
        return getPerMill(s, c);
    }
    
    static char access$3000(String s, char c) {
        return getZeroDigit(s, c);
    }
    
    static int access$3100(String s, int n) {
        return getCalendarDataValue(s, n);
    }
    
    static String access$3500(String s, int n, String s2) {
        return getDisplayString(s, n, s2);
    }
    
    static {
        calIDToLDML = new String[] { "", "gregory", "gregory_en-US", "japanese", "roc", "", "islamic", "buddhist", "hebrew", "gregory_fr", "gregory_ar", "gregory_en", "gregory_fr" };
        HostLocaleProviderAdapterImpl.dateFormatCache = new ConcurrentHashMap();
        HostLocaleProviderAdapterImpl.dateFormatSymbolsCache = new ConcurrentHashMap();
        HostLocaleProviderAdapterImpl.numberFormatCache = new ConcurrentHashMap();
        HostLocaleProviderAdapterImpl.decimalFormatSymbolsCache = new ConcurrentHashMap();
        HashSet<Object> s = new HashSet();
        if (initialize()) {
            ResourceBundle.Control noFallbackControl = ResourceBundle.Control.getNoFallbackControl(ResourceBundle.Control.FORMAT_DEFAULT);
            String defaultLocale = getDefaultLocale(0);
            Locale forLanguageTag = Locale.forLanguageTag(defaultLocale.replace('_', '-'));
            s.addAll(noFallbackControl.getCandidateLocales("", forLanguageTag));
            nativeDisplayLanguage = forLanguageTag.getLanguage();
            String defaultLocale2 = getDefaultLocale(1);
            if (!defaultLocale2.equals(defaultLocale)) {
                s.addAll(noFallbackControl.getCandidateLocales("", Locale.forLanguageTag(defaultLocale2.replace('_', '-'))));
            }
        }
        else {
            nativeDisplayLanguage = "";
        }
        supportedLocaleSet = Collections.unmodifiableSet(s);
        supportedLocale = (Locale[])HostLocaleProviderAdapterImpl.supportedLocaleSet.toArray(new Locale[0]);
    }
}
